/*******************************************************************************
* File Name: SERIAL_BOOT.h
* Version 2.0
*
* Description:
*  This file provides constants and parameter values for the bootloader
*  communication interface of SCB component.
*
* Note:
*
********************************************************************************
* Copyright 2014, Cypress Semiconductor Corporation. All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_SCB_BOOT_SERIAL_H)
#define CY_SCB_BOOT_SERIAL_H

#include "SERIAL_PVT.h"

#if (SERIAL_SCB_MODE_I2C_INC)
    #include "SERIAL_I2C.h"
#endif /* (SERIAL_SCB_MODE_I2C_INC) */

#if (SERIAL_SCB_MODE_EZI2C_INC)
    #include "SERIAL_EZI2C.h"
#endif /* (SERIAL_SCB_MODE_EZI2C_INC) */

#if (SERIAL_SCB_MODE_SPI_INC || SERIAL_SCB_MODE_UART_INC)
    #include "SERIAL_SPI_UART.h"
#endif /* (SERIAL_SCB_MODE_SPI_INC || SERIAL_SCB_MODE_UART_INC) */


/***************************************
*        Function Prototypes
***************************************/

/* Bootloader communication interface enable */
#define SERIAL_BTLDR_COMM_ENABLED ((CYDEV_BOOTLOADER_IO_COMP == CyBtldr_SERIAL) || \
                                             (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_Custom_Interface))

#if (SERIAL_SCB_MODE_I2C_INC)

    #define SERIAL_I2C_BTLDR_COMM_ENABLED     (SERIAL_BTLDR_COMM_ENABLED && \
                                                            (SERIAL_SCB_MODE_UNCONFIG_CONST_CFG || \
                                                             SERIAL_I2C_SLAVE_CONST))

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SERIAL_I2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void SERIAL_I2CCyBtldrCommStart(void);
    void SERIAL_I2CCyBtldrCommStop (void);
    void SERIAL_I2CCyBtldrCommReset(void);
    cystatus SERIAL_I2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SERIAL_I2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);

    /* Size of Read/Write buffers for I2C bootloader  */
    #define SERIAL_I2C_BTLDR_SIZEOF_READ_BUFFER   (64u)
    #define SERIAL_I2C_BTLDR_SIZEOF_WRITE_BUFFER  (64u)
    #define SERIAL_I2C_MIN_UINT16(a, b)           ( ((uint16)(a) < (uint16) (b)) ? \
                                                                    ((uint32) (a)) : ((uint32) (b)) )
    #define SERIAL_WAIT_1_MS                      (1u)
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SERIAL_I2C_BTLDR_COMM_ENABLED) */

#endif /* (SERIAL_SCB_MODE_I2C_INC) */


#if (SERIAL_SCB_MODE_EZI2C_INC)

    /* Provide EMPTY bootloader communication functions. EZI2C is NOT supported yet */
    #define SERIAL_EZI2C_BTLDR_COMM_ENABLED   (SERIAL_BTLDR_COMM_ENABLED && \
                                                         SERIAL_SCB_MODE_UNCONFIG_CONST_CFG)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SERIAL_EZI2C_BTLDR_COMM_ENABLED)
    /* Bootloader physical layer functions */
    void SERIAL_EzI2CCyBtldrCommStart(void);
    void SERIAL_EzI2CCyBtldrCommStop (void);
    void SERIAL_EzI2CCyBtldrCommReset(void);
    cystatus SERIAL_EzI2CCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SERIAL_EzI2CCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SERIAL_EZI2C_BTLDR_COMM_ENABLED) */

#endif /* (SERIAL_SCB_MODE_EZI2C_INC) */

#if (SERIAL_SCB_MODE_SPI_INC || SERIAL_SCB_MODE_UART_INC)
    /* Provide EMPTY bootloader communication functions. SPI and UART is NOT supported yet */
    #define SERIAL_SPI_BTLDR_COMM_ENABLED     (SERIAL_BTLDR_COMM_ENABLED && \
                                                        SERIAL_SCB_MODE_UNCONFIG_CONST_CFG)

    #define SERIAL_UART_BTLDR_COMM_ENABLED    (SERIAL_BTLDR_COMM_ENABLED && \
                                                        SERIAL_SCB_MODE_UNCONFIG_CONST_CFG)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SERIAL_SPI_BTLDR_COMM_ENABLED)
    /* SPI Bootloader physical layer functions */
    void SERIAL_SpiCyBtldrCommStart(void);
    void SERIAL_SpiCyBtldrCommStop (void);
    void SERIAL_SpiCyBtldrCommReset(void);
    cystatus SERIAL_SpiCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SERIAL_SpiCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SERIAL_SPI_BTLDR_COMM_ENABLED) */

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SERIAL_UART_BTLDR_COMM_ENABLED)
    /* UART Bootloader physical layer functions */
    void SERIAL_UartCyBtldrCommStart(void);
    void SERIAL_UartCyBtldrCommStop (void);
    void SERIAL_UartCyBtldrCommReset(void);
    cystatus SERIAL_UartCyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    cystatus SERIAL_UartCyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SERIAL_UART_BTLDR_COMM_ENABLED) */

#endif /* (SERIAL_SCB_MODE_SPI_INC || SERIAL_SCB_MODE_UART_INC) */

#if !defined (SERIAL_I2C_BTLDR_COMM_ENABLED)
    #define SERIAL_I2C_BTLDR_COMM_ENABLED     (0u)
#endif /* (SERIAL_I2C_BTLDR_COMM_ENABLED) */

#if !defined (SERIAL_EZI2C_BTLDR_COMM_ENABLED)
    #define SERIAL_EZI2C_BTLDR_COMM_ENABLED   (0u)
#endif /* (SERIAL_EZI2C_BTLDR_COMM_ENABLED) */

#if !defined (SERIAL_SPI_BTLDR_COMM_ENABLED)
    #define SERIAL_SPI_BTLDR_COMM_ENABLED     (0u)
#endif /* (SERIAL_SPI_BTLDR_COMM_ENABLED) */

#if !defined (SERIAL_UART_BTLDR_COMM_ENABLED)
    #define SERIAL_UART_BTLDR_COMM_ENABLED    (0u)
#endif /* (SERIAL_UART_BTLDR_COMM_ENABLED) */

/* Bootloader enabled condition for each mode */
#define SERIAL_BTLDR_COMM_MODE_ENABLED    (SERIAL_I2C_BTLDR_COMM_ENABLED   || \
                                                     SERIAL_EZI2C_BTLDR_COMM_ENABLED || \
                                                     SERIAL_SPI_BTLDR_COMM_ENABLED   || \
                                                     SERIAL_UART_BTLDR_COMM_ENABLED)

#if defined(CYDEV_BOOTLOADER_IO_COMP) && (SERIAL_BTLDR_COMM_ENABLED)
    #if (SERIAL_BTLDR_COMM_MODE_ENABLED)
        /* Bootloader physical layer functions */
        void SERIAL_CyBtldrCommStart(void);
        void SERIAL_CyBtldrCommStop (void);
        void SERIAL_CyBtldrCommReset(void);
        cystatus SERIAL_CyBtldrCommRead       (uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
        cystatus SERIAL_CyBtldrCommWrite(const uint8 pData[], uint16 size, uint16 * count, uint8 timeOut);
    #endif /* (SERIAL_BTLDR_COMM_MODE_ENABLED) */

    #if (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_SERIAL)
        #define CyBtldrCommStart    SERIAL_CyBtldrCommStart
        #define CyBtldrCommStop     SERIAL_CyBtldrCommStop
        #define CyBtldrCommReset    SERIAL_CyBtldrCommReset
        #define CyBtldrCommWrite    SERIAL_CyBtldrCommWrite
        #define CyBtldrCommRead     SERIAL_CyBtldrCommRead
    #endif /* (CYDEV_BOOTLOADER_IO_COMP == CyBtldr_SERIAL) */
#endif /* defined(CYDEV_BOOTLOADER_IO_COMP) && (SERIAL_BTLDR_COMM_ENABLED) */

#endif /* (CY_SCB_BOOT_SERIAL_H) */

/* [] END OF FILE */
